@@ -1,19 +1,15 @@
 # -*- coding: utf-8 -*-
 import sys
-import os
-os.environ['lanas'] = 'enabled'
-
-sys.path.append("kanzen")
 
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 
 import interprete
 
-def main():
+def main(with_log=False):
     app = QApplication(sys.argv)
     app.setApplicationName('Lanas')
-    win = interprete.Ventana()
+    win = interprete.Ventana(with_log=with_log)
     win.show()
     win.raise_()
     sys.exit(app.exec_())
