@@ -45,9 +45,10 @@ Este módulo contiene las funciones principales
 para iniciar y ejecutar la biblioteca.
 """
 
+
 def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='qtgl',
             rendimiento=60, modo='detectar', gravedad=(0, -90), pantalla_completa=False,
-            permitir_depuracion=True, audio='phonon', centrado=True):
+            permitir_depuracion=True, audio='deshabilitado', centrado=True):
     """
     Inicia la ventana principal del juego con algunos detalles de funcionamiento.
 
@@ -68,6 +69,7 @@ def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='qtgl',
     :gravedad: el vector de aceleracion para la simulacion de fisica.
     :pantalla_completa: si debe usar pantalla completa o no.
     :permitir_depuracion: si se desea tener habilidatas las funciones de depuracion de las teclas F5 a F12
+    :audio: selecciona el motor de sonido a utilizar, los valores permitidos son 'deshabilitado', 'phonon' o 'gst'.
     :centrado: Indica si se desea centrar la ventana de pilas.
     """
 
@@ -93,9 +95,9 @@ def esta_inicializada():
     return isinstance(mundo, Mundo)
 
 
-def iniciar_con_lanzador(ancho=640, alto=480, titulo='Pilas',
-            rendimiento=60, modo='detectar', gravedad=(0, -90), imagen="asistente.png",
-            permitir_depuracion=True):
+def iniciar_con_lanzador(ancho=640, alto=480, titulo='Pilas', rendimiento=60,
+                         modo='detectar', gravedad=(0, -90), imagen="asistente.png",
+                         permitir_depuracion=True):
     """Identica a la función iniciar, solo que permite al usuario seleccionar
     el motor multimedia y el modo de video a utilizar.
 
@@ -120,26 +122,31 @@ def abrir_asistente():
     import asistente
     asistente.ejecutar()
 
+
 def ejecutar(ignorar_errores=False):
     """Pone en funcionamiento las actualizaciones y dibujado.
 
     Esta función es necesaria cuando se crea un juego
     en modo ``no-interactivo``."""
-    mundo.ejecutar_bucle_principal(ignorar_errores)
+    mundo.ejecutar_bucle_principal()
+
 
 def terminar():
     """Finaliza la ejecución de pilas y cierra la ventana principal."""
     mundo.terminar()
 
+
 def ver(objeto, imprimir=True, retornar=False):
     """Imprime en pantalla el codigo fuente asociado a un objeto."""
     return utils.ver_codigo(objeto, imprimir, retornar)
 
+
 def version():
     """Retorna el número de version de pilas."""
     import pilasversion
     return pilasversion.VERSION
 
+
 def _crear_motor(usar_motor, permitir_depuracion, audio):
     """Genera instancia del motor multimedia en base a un nombre.
 
@@ -154,21 +161,24 @@ def _crear_motor(usar_motor, permitir_depuracion, audio):
 
         motor = motor_qt.Motor(usar_motor, permitir_depuracion, audio)
     else:
-        print "El motor multimedia seleccionado (%s) no esta disponible" %(usar_motor)
+        print "El motor multimedia seleccionado (%s) no esta disponible" % (usar_motor)
         print "Las opciones de motores que puedes probar son 'qt', 'qtgl', 'qtwidget', 'qtsugar' y 'qtsugargl'."
         motor = None
 
     return motor
 
+
 def _usa_interprete_lanas():
     "Retorna True si se ha iniciado pilas desde lanas"
     import os
-    return os.environ.has_key('lanas')
+    return 'lanas' in os.environ
+
 
 def reiniciar():
     """Elimina todos los actores y vuelve al estado inicial."""
     mundo.reiniciar()
 
+
 def avisar(mensaje, retraso=5):
     """Emite un mensaje en la ventana principal.
 
@@ -179,6 +189,7 @@ def avisar(mensaje, retraso=5):
     """
     actores.TextoInferior(mensaje, autoeliminar=True, retraso=retraso)
 
+
 def abrir_cargador():
     """Abre un cargador de ejemplos con varios códigos de prueba.
 
@@ -200,6 +211,7 @@ def abrir_cargador():
 
     return []
 
+
 def abrir_interprete(parent=None, do_raise=False, con_aplicacion=False):
     """Abre un intérprete interactivo de python con una ventana.
 
@@ -216,20 +228,25 @@ def abrir_interprete(parent=None, do_raise=False, con_aplicacion=False):
 
     interprete.main(parent, do_raise)
 
+
 def log(*parametros):
     eventos.log.emitir(data=parametros)
 
 interpolar = utils.interpolar
 
+
 def escena_actual():
     return mundo.gestor_escenas.escena_actual()
 
+
 def cambiar_escena(escena):
     mundo.gestor_escenas.cambiar_escena(escena)
 
+
 def almacenar_escena(escena):
     mundo.gestor_escenas.almacenar_escena(escena)
 
+
 def recuperar_escena():
     mundo.gestor_escenas.recuperar_escena()
 
