@@ -10,14 +10,15 @@ import pilas
 from pilas.actores import Animacion
 from pilas.actores import Explosion
 
+
 class Bomba(Animacion):
-    """Representa una explosion para una bomba, dinamita etc...
+    """Representa una bomba que puede explotar...
 
     .. image:: images/actores/bomba.png
 
     La bomba adquiere la habilidad explotar al momento de crearse, así
     que puedes invocar a su método "explotar" y la bomba hará un
-    explosión con sonido en pantalla.
+    explosión en pantalla con sonido.
 
     Este es un ejemplo de uso del actor:
 
@@ -25,13 +26,19 @@ class Bomba(Animacion):
         >>> bomba.explotar()
     """
 
-
     def __init__(self, x=0, y=0):
+        """ Constructor de la Bomba.
+
+        :param x: Posición horizontal del Actor.
+        :type x: int
+        :param y: Posición vertical del Actor.
+        :type y: int
+        """
         grilla = pilas.imagenes.cargar_grilla("bomba.png", 2)
         Animacion.__init__(self, grilla, ciclica=True, x=x, y=y)
         self.radio_de_colision = 25
         self.aprender(pilas.habilidades.PuedeExplotar)
 
     def explotar(self):
-        "Hace explotar a la bomba y la elimina de la pantalla."
+        """Hace explotar a la bomba y la elimina de la pantalla."""
         self.eliminar()
