@@ -19,12 +19,14 @@ ESTE = 1
 OESTE = 3
 
 class BasePersonajeRPG(Actor):
+    """Representa un personaje de juego tipo RPG."""
+
     def __init__(self, mapa, x=0, y=0, imagen="rpg/calvo.png", velocidad=3):
         Actor.__init__(self, x=x, y=y)
         self.imagen = pilas.imagenes.cargar_grilla(imagen, 3, 4)
-        
+
         self.mapa = mapa
-        
+
         self.direccion = pilas.actores.personajes_rpg.SUR
         self.hacer(Esperando())
         self.velocidad = velocidad
@@ -40,6 +42,11 @@ class Esperando(Comportamiento):
     "Un actor en posicion normal o esperando a que el usuario pulse alguna tecla."
 
     def iniciar(self, receptor):
+        """Inicializa el comportamiento.
+
+        :param receptor: Referencia al actor a controlar.
+        """
+
         self.receptor = receptor
         if (self.receptor.direccion == pilas.actores.personajes_rpg.NORTE):
             self.receptor.definir_cuadro(1)
@@ -61,29 +68,34 @@ class Esperando(Comportamiento):
             self.receptor.hacer(Caminando())
 
 class Caminando(Esperando):
+    """Representa al personaje caminando por el escenario."""
 
     def __init__(self):
         self._repeticion_cuadro = 3
-        
+
         self.cuadros = [[1,1,1,1,0,0,0,0,1,1,1,1,2,2,2,2],
                         [4,4,4,4,3,3,3,3,4,4,4,4,5,5,5,5],
                         [7,7,7,7,6,6,6,6,7,7,7,7,8,8,8,8],
                         [10,10,10,10,9,9,9,9,10,10,10,10,11,11,11,11]]
-                
+
         self.paso = 0
 
     def iniciar(self, receptor):
+        """Inicializa el comportamiento.
+
+        :param receptor: Referencia al actor a controlar.
+        """
         self.receptor = receptor
 
     def actualizar(self):
         self.avanzar_animacion()
-        
+
         dx = 0
         dy = 0
 
         if pilas.escena_actual().control.izquierda:
             dx = self.receptor.velocidad * -1
-            self.receptor.direccion = pilas.actores.personajes_rpg.OESTE            
+            self.receptor.direccion = pilas.actores.personajes_rpg.OESTE
         elif pilas.escena_actual().control.derecha:
             dx = self.receptor.velocidad
             self.receptor.direccion = pilas.actores.personajes_rpg.ESTE
@@ -101,6 +113,7 @@ class Caminando(Esperando):
             self.receptor.y += dy
 
     def avanzar_animacion(self):
+        """Cambia el cuadro de animación."""
         self.paso += 1
 
         if self.paso >= len(self.cuadros[self.receptor.direccion]):
@@ -109,11 +122,25 @@ class Caminando(Esperando):
         self.receptor.definir_cuadro(self.cuadros[self.receptor.direccion][self.paso])
 
 class Calvo(BasePersonajeRPG):
+    """Representa un personaje de juego tipo RPG."""
 
     def __init__(self, mapa, x=0, y=0):
+        """Inicializa al actor.
+
+        :param mapa: Mapa sobre el que podrá moverse el actor.
+        :param x: Posición horizontal del mapa.
+        :param y: Posición vertical del mapa.
+        """
         BasePersonajeRPG.__init__(self, mapa=mapa, x=x, y=y, imagen="rpg/calvo.png", velocidad=2)
 
 class Maton(BasePersonajeRPG):
+    """Representa un personaje de juego tipo RPG."""
 
     def __init__(self, mapa, x=0, y=0):
+        """Inicializa al actor.
+
+        :param mapa: Mapa sobre el que podrá moverse el actor.
+        :param x: Posición horizontal del mapa.
+        :param y: Posición vertical del mapa.
+        """
         BasePersonajeRPG.__init__(self, mapa, x=x, y=y, imagen="rpg/maton.png", velocidad=2)
