@@ -50,11 +50,18 @@ def crear_motor_fisica(area, gravedad):
 
 def obtener_version():
     """Obtiene la versión de la biblioteca Box2D"""
-    return box2d.__version__
+    if __enabled__:
+        return box2d.__version__
+    else:
+        '0.0_error'
+
 
 def obtener_version_en_tupla():
     """Obtiene la versión de la biblioteca Box2D"""
-    return box2d.__version_info__
+    if __enabled__:
+        return box2d.__version_info__
+    else:
+        return (0, 0, 0)
 
 class Fisica(object):
     """Representa un simulador de mundo fisico, usando la biblioteca Box2D (version 2.1)."""
@@ -371,7 +378,7 @@ class Figura(object):
 
     def impulsar(self, dx, dy):
         # TODO: convertir los valores dx y dy a metros.
-        self._cuerpo.ApplyLinearImpulse((dx, dy), (0, 0))
+        self._cuerpo.ApplyLinearImpulse((dx, dy), (0, 0), True)
 
     def obtener_velocidad_lineal(self):
         # TODO: convertir a pixels
