@@ -14,10 +14,15 @@ import utils
 
 try:
     sys.path.append(utils.obtener_ruta_al_recurso('../lanas'))
+except IOError, e:
+    pass
+
+try:
     import lanas
 except ImportError, e:
     print e
 
+
 import os
 
 if os.environ.has_key('lanas'):
@@ -33,6 +38,15 @@ class VentanaInterprete(Ui_InterpreteDialog):
         pilas.utils.centrar_ventana(main)
         pilas.utils.centrar_ventana(main)
 
+
+    def raw_input(self, mensaje):
+        text, state = QtGui.QInputDialog.getText(self, "raw_input", mensaje)
+        return str(text)
+
+    def input(self, mensaje):
+        text, state = QtGui.QInputDialog.getText(self, "raw_input", mensaje)
+        return eval(str(text))
+
     def _insertar_ventana_principal_de_pilas(self):
         pilas.iniciar(usar_motor='qtsugar', ancho=640, alto=400)
 
@@ -45,7 +59,7 @@ class VentanaInterprete(Ui_InterpreteDialog):
 
         self.canvas.addWidget(ventana)
         self.canvas.setCurrentWidget(ventana)
-        return {'pilas': pilas, 'mono': mono}
+        return {'pilas': pilas, 'mono': mono, 'self': self}
 
     def _insertar_consola_interactiva(self, scope):
         codigo_inicial = [
