@@ -12,10 +12,13 @@ from PyQt4.QtOpenGL import QGLWidget
 from PyQt4.QtGui import QWidget
 from pilas import actores, colores, depurador, eventos, fps
 from pilas import imagenes, simbolos, utils
+from pilas import dev
 import os
 import pilas
 import sys
 import traceback
+import copy
+
 
 class LibreriaImagenes(object):
     """ Clase que permite cachear las imagenes cargadas en el juego."""
@@ -53,11 +56,12 @@ class LibreriaImagenes(object):
         :type indice: string
 
         """
-        return self._imagenes.has_key(indice)
+        return indice in self._imagenes
 
     def obtener_cantidad(self):
         return len(self._imagenes)
 
+
 class Ventana(QtGui.QMainWindow):
 
     def __init__(self, parent=None):
@@ -74,16 +78,20 @@ class Ventana(QtGui.QMainWindow):
 
 class CanvasWidgetAbstracto(object):
 
-    def __init__(self, motor, lista_actores, ancho, alto, gestor_escenas, permitir_depuracion, rendimiento):
+    def __init__(self, motor, ancho, alto, gestor_escenas, permitir_depuracion,
+                 rendimiento):
         QGLWidget.__init__(self, None)
+
         self.painter = QtGui.QPainter()
-        self.setMouseTracking(True)
 
         self.pausa_habilitada = False
+
+        self.setMouseTracking(True)
         self.mouse_x = 0
         self.mouse_y = 0
+
         self.motor = motor
-        self.lista_actores = lista_actores
+
         self.fps = fps.FPS(rendimiento, True)
 
         if permitir_depuracion:
@@ -93,7 +101,9 @@ class CanvasWidgetAbstracto(object):
 
         self.original_width = ancho
         self.original_height = alto
+
         self.escala = 1
+
         self.startTimer(1000/100.0)
 
         self.gestor_escenas = gestor_escenas
@@ -123,12 +133,9 @@ class CanvasWidgetAbstracto(object):
         self.painter.fillRect(0, 0, self.original_width, self.original_height, QtGui.QColor(128, 128, 128))
         self.depurador.comienza_dibujado(self.motor, self.painter)
 
-        actores_a_eliminar = []
-
         if self.gestor_escenas.escena_actual():
             actores_de_la_escena = self.gestor_escenas.escena_actual().actores
             for actor in actores_de_la_escena:
-                #if actor._vivo:
                 try:
                     if not actor.esta_fuera_de_la_pantalla():
                         actor.dibujar(self.painter)
@@ -138,11 +145,6 @@ class CanvasWidgetAbstracto(object):
                     actor.eliminar()
 
                 self.depurador.dibuja_al_actor(self.motor, self.painter, actor)
-                #else:
-                #    actores_a_eliminar.append(actor)
-
-                #for x in actores_a_eliminar:
-                #    actores_de_la_escena.remove(x)
 
         self.depurador.termina_dibujado(self.motor, self.painter)
         self.painter.end()
@@ -182,9 +184,6 @@ class CanvasWidgetAbstracto(object):
 
         izquierda, derecha, arriba, abajo = utils.obtener_bordes()
 
-        #x = max(min(derecha, x), izquierda)
-        #y = max(min(arriba, y), abajo)
-
         x += pilas.mundo.motor.camara_x
         y += pilas.mundo.motor.camara_y
 
@@ -324,6 +323,7 @@ class CanvasWidgetAbstracto(object):
         else:
             self.pantalla_completa()
 
+
 class BaseActor(object):
 
     def __init__(self):
@@ -388,7 +388,7 @@ class Imagen(object):
         else:
             self._imagen = QtGui.QPixmap(ruta)
 
-        pilas.mundo.motor.libreria_imagenes.agregar_imagen(self)
+        #pilas.mundo.motor.libreria_imagenes.agregar_imagen(self)
 
     def cargar_jpeg(self, ruta):
         from PIL import Image
@@ -442,14 +442,17 @@ class Imagen(object):
 
     def __str__(self):
         nombre_imagen = os.path.basename(self.ruta_original)
-        return "<Imagen del archivo '%s'>" %(nombre_imagen)
+        return "<Imagen del archivo '%s'>" % (nombre_imagen)
+
 
 class CanvasOpenGlWidget(CanvasWidgetAbstracto, QGLWidget):
     pass
 
+
 class CanvasNormalWidget(CanvasWidgetAbstracto, QWidget):
     pass
 
+
 class Grilla(Imagen):
 
     """Representa una grilla regular, que se utiliza en animaciones.
@@ -505,7 +508,6 @@ class Grilla(Imagen):
         pizarra.pintar_parte_de_imagen(self, self.dx, self.dy, self.cuadro_ancho, self.cuadro_alto, x, y)
 
 
-
 class Lienzo(Imagen):
 
     def __init__(self):
@@ -568,7 +570,7 @@ class Lienzo(Imagen):
         color = QtGui.QColor(r, g, b)
         pen = QtGui.QPen(color, grosor)
         painter.setPen(pen)
-        painter.drawEllipse(x -radio, y-radio, radio*2, radio*2)
+        painter.drawEllipse(x-radio, y-radio, radio*2, radio*2)
 
     def rectangulo(self, painter, x, y, ancho, alto, color=colores.negro, grosor=1):
         x, y = utils.hacer_coordenada_pantalla_absoluta(x, y)
@@ -633,7 +635,7 @@ class Superficie(Imagen):
         if relleno:
             self.canvas.setBrush(color)
 
-        self.canvas.drawEllipse(x -radio, y-radio, radio*2, radio*2)
+        self.canvas.drawEllipse(x-radio, y-radio, radio*2, radio*2)
         self.canvas.end()
 
     def rectangulo(self, x, y, ancho, alto, color=colores.negro, relleno=False, grosor=1):
@@ -678,6 +680,7 @@ class Superficie(Imagen):
     def limpiar(self):
         self._imagen.fill(QtGui.QColor(0, 0, 0, 0))
 
+
 class Texto(Superficie):
     CACHE_FUENTES = {}
 
@@ -685,7 +688,7 @@ class Texto(Superficie):
         ancho, alto = motor.obtener_area_de_texto(texto, magnitud, vertical, fuente)
         Superficie.__init__(self, ancho, alto)
         self.texto(texto, magnitud=magnitud, fuente=fuente, color=color)
-        self.ruta_original = texto.encode('ascii','xmlcharrefreplace') + str(os.urandom(25))
+        self.ruta_original = texto.encode('ascii', 'xmlcharrefreplace') + str(os.urandom(25))
 
     @classmethod
     def cargar_fuente_desde_cache(kclass, fuente_como_ruta):
@@ -712,23 +715,22 @@ class Texto(Superficie):
         return str(QtGui.QFontDatabase.applicationFontFamilies(fuente_id)[0])
 
 
-
 class Actor(BaseActor):
 
     def __init__(self, imagen="sin_imagen.png", x=0, y=0):
 
         # Si la imagen es una cadena, cargamos la imagen y la cacheamos.
-        if isinstance(imagen, str):
-            self.indice_imagen = pilas.mundo.motor.libreria_imagenes.agregar_imagen(imagenes.cargar(imagen))
-        else:
-            # Si en un objeto Imagen lo almacenamos directamente.
-            self.indice_imagen = pilas.mundo.motor.libreria_imagenes.agregar_imagen(imagen)
+        #if isinstance(imagen, str):
+        #    self.indice_imagen = pilas.mundo.motor.libreria_imagenes.agregar_imagen(imagenes.cargar(imagen))
+        #else:
+        #    # Si en un objeto Imagen lo almacenamos directamente.
+        #    self.indice_imagen = pilas.mundo.motor.libreria_imagenes.agregar_imagen(imagen)
+        self.imagen = imagen
 
         self.x = x
         self.y = y
         BaseActor.__init__(self)
 
-
     def get_imagen(self):
         """ Obtinene la imagen del Actor. """
         return self.obtener_imagen()
@@ -739,7 +741,14 @@ class Actor(BaseActor):
         :param imagen: Imagen que definirá al actor.
         :type imagen: Imagen, Grilla,
         """
+        if isinstance(imagen, Grilla):
+            self._imagen = copy.copy(imagen)
+        elif isinstance(imagen, str):
+            self._imagen = pilas.imagenes.cargar(imagen)
+        else:
+            self._imagen = imagen
 
+        """
         # Comprobamos si el parametro imagen es un objeto Imagen o Grilla.
         if isinstance(imagen, Imagen) or isinstance(imagen, Grilla):
             # Comprobamos si ya está cacheada esa imagen.
@@ -759,6 +768,7 @@ class Actor(BaseActor):
                     self.indice_imagen = pilas.mundo.motor.libreria_imagenes.agregar_imagen(imagenes.cargar(imagen))
             else:
                 raise Exception("Lo siento, solo se admiten rutas a archivos o imagenes.")
+        """
 
     imagen = property(get_imagen, set_imagen, doc="")
 
@@ -766,7 +776,8 @@ class Actor(BaseActor):
         self.imagen = imagen
 
     def obtener_imagen(self):
-        return pilas.mundo.motor.libreria_imagenes.obtener_imagen(self.indice_imagen)
+        #return pilas.mundo.motor.libreria_imagenes.obtener_imagen(self.indice_imagen)
+        return self._imagen
 
     def dibujar(self, painter):
         escala_x, escala_y = self._escala_x, self._escala_y
@@ -784,8 +795,11 @@ class Actor(BaseActor):
         x = self.x - dx
         y = self.y - dy
 
-        pilas.mundo.motor.libreria_imagenes.obtener_imagen(self.indice_imagen).dibujar(painter, x, y, self.centro_x, self.centro_y,
-                escala_x, escala_y, self._rotacion, self._transparencia)
+        #pilas.mundo.motor.libreria_imagenes.obtener_imagen(self.indice_imagen).dibujar(painter, x, y, self.centro_x, self.centro_y,
+        #        escala_x, escala_y, self._rotacion, self._transparencia)
+        #self.imagen.dibujar(painter, x, y, self.centro_x, self.centro_y)
+        self.imagen.dibujar(painter, x, y, self.centro_x, self.centro_y,
+                            escala_x, escala_y, self._rotacion, self._transparencia)
 
 
 ## Backend: audio deshabilitado
@@ -808,6 +822,7 @@ class SonidoDeshabilitado:
     def continuar(self):
         pass
 
+
 class MusicaDeshabilitada(SonidoDeshabilitado):
 
     def __init__(self, media, ruta):
@@ -815,6 +830,7 @@ class MusicaDeshabilitada(SonidoDeshabilitado):
 
 ## Backend: gstreamer
 
+
 class SonidoGST:
     deshabilitado = False
 
@@ -838,7 +854,7 @@ class SonidoGST:
             if repetir:
                 self.sonido.get_state()
                 nanosecs = float(self.sonido.query_duration(gst.FORMAT_TIME)[0])
-                duracion =  (nanosecs + 10) / gst.SECOND
+                duracion = (nanosecs + 10) / gst.SECOND
                 self._repetir = pilas.mundo.agregar_tarea_siempre(duracion,
                                                                   self._play)
 
@@ -857,6 +873,7 @@ class MusicaGST(SonidoGST):
 
 ## Backend: audio phonon
 
+
 class SonidoPhonon:
     deshabilitado = False
 
@@ -922,7 +939,7 @@ class Motor(object):
     def __init__(self, usar_motor, permitir_depuracion, audio):
         import sys
 
-	if not '-i' in sys.argv:
+        if not '-i' in sys.argv:
             self._iniciar_aplicacion()
 
         self.usar_motor = usar_motor
@@ -933,7 +950,6 @@ class Motor(object):
         self._inicializar_variables()
         self._inicializar_sistema_de_audio(audio)
 
-
     def _iniciar_aplicacion(self):
         self.app = QtGui.QApplication([])
         self.app.setApplicationName("pilas")
@@ -947,8 +963,8 @@ class Motor(object):
         sistemas_de_sonido = ['deshabilitado', 'phonon', 'gst']
 
         if audio not in sistemas_de_sonido:
-            error = "El sistema de audio '%s' es invalido" %(audio)
-            sugerencia = ". Use alguno de los siguientes: %s" %(str(sistemas_de_sonido))
+            error = "El sistema de audio '%s' es invalido" % (audio)
+            sugerencia = ". Use alguno de los siguientes: %s" % (str(sistemas_de_sonido))
             raise Exception(error + sugerencia)
 
         if audio == 'gst':
@@ -971,7 +987,6 @@ class Motor(object):
             self.clase_sonido = SonidoPhonon
             self.clase_musica = MusicaPhonon
         elif audio == 'gst':
-            import gst
             self.player = gst.element_factory_make("playbin2", "player")
             self.clase_sonido = SonidoGST
             self.clase_musica = MusicaGST
@@ -979,7 +994,8 @@ class Motor(object):
     def terminar(self):
         self.ventana.close()
 
-    def iniciar_ventana(self, ancho, alto, titulo, pantalla_completa, gestor_escenas, rendimiento, centrado):
+    def iniciar_ventana(self, ancho, alto, titulo, pantalla_completa,
+                        gestor_escenas, rendimiento, centrado):
         self.ventana = Ventana()
         self.ventana.resize(ancho, alto)
 
@@ -990,9 +1006,11 @@ class Motor(object):
         mostrar_ventana = True
 
         if self.usar_motor == 'qtgl':
-            self.canvas = CanvasOpenGlWidget(self, actores.todos, ancho, alto, gestor_escenas, self.permitir_depuracion, rendimiento)
+            self.canvas = CanvasOpenGlWidget(self, ancho, alto, gestor_escenas,
+                                             self.permitir_depuracion, rendimiento)
         else:
-            self.canvas = CanvasNormalWidget(self, actores.todos, ancho, alto, gestor_escenas, self.permitir_depuracion, rendimiento)
+            self.canvas = CanvasNormalWidget(self, ancho, alto, gestor_escenas,
+                                             self.permitir_depuracion, rendimiento)
 
         self.ventana.set_canvas(self.canvas)
         self.canvas.setFocus()
@@ -1027,7 +1045,7 @@ class Motor(object):
     def mostrar_puntero_del_mouse(self):
         self.canvas.setCursor(QtGui.QCursor(Qt.ArrowCursor))
 
-    def ejecutar_bucle_principal(self, mundo, ignorar_errores):
+    def ejecutar_bucle_principal(self):
         if getattr(self, 'app', None):
             sys.exit(self.app.exec_())
 
@@ -1042,6 +1060,8 @@ class Motor(object):
         "Centro de la ventana para situar el punto (0, 0)"
         return self.ancho_original/2, self.alto_original/2
 
+    @dev.deprecated(se_desactiva_en="0.80", se_elimina_en="0.81",
+                    reemplazo="pilas.mundo.obtener_area")
     def obtener_area(self):
         return (self.ancho_original, self.alto_original)
 
@@ -1066,10 +1086,15 @@ class Motor(object):
             lineas = cadena.split('\n')
 
         for line in lineas:
-            brect = p.drawText(QtCore.QRect(0,0, 1024, 768), QtCore.Qt.AlignLeft | QtCore.Qt.AlignTop, line)
+            if line == '':
+                line = ' '
+
+            brect = p.drawText(QtCore.QRect(0, 0, 1024, 768),
+                               QtCore.Qt.AlignLeft | QtCore.Qt.AlignTop, line)
             ancho = max(ancho, brect.size().width())
             alto += brect.size().height()
 
+
         p.end()
         return (ancho, alto)
 
@@ -1095,10 +1120,11 @@ class Motor(object):
         self.clase_musica.deshabilitado = estado
 
     def cargar_imagen(self, ruta):
-        if pilas.mundo.motor.libreria_imagenes.tiene(ruta):
-            return pilas.mundo.motor.libreria_imagenes.obtener_imagen(ruta)
-        else:
-            return Imagen(ruta)
+        #if pilas.mundo.motor.libreria_imagenes.tiene(ruta):
+        #    return pilas.mundo.motor.libreria_imagenes.obtener_imagen(ruta)
+        #else:
+        #  return Imagen(ruta)
+        return Imagen(ruta)
 
     def obtener_lienzo(self):
         return Lienzo()
