@@ -16,7 +16,6 @@ import pilas
 import mimetypes
 
 
-
 PATH = os.path.dirname(os.path.abspath(__file__))
 
 
@@ -38,8 +37,7 @@ def obtener_ruta_al_recurso(ruta):
     :param ruta: Ruta al archivo (recurso) a inspeccionar.
     """
 
-    dirs = ['./', os.path.dirname(sys.argv[0]), 'data', PATH, PATH + '/data']
-
+    dirs = ['./', os.path.dirname(sys.argv[0]), os.path.dirname(sys.argv[0])  + '/data', 'data', PATH, PATH + '/data']
 
     for x in dirs:
         full_path = os.path.join(x, ruta)
@@ -49,7 +47,7 @@ def obtener_ruta_al_recurso(ruta):
             return full_path
 
     # Si no ha encontrado el archivo lo reporta.
-    raise IOError("El archivo '%s' no existe." %(ruta))
+    raise IOError("El archivo '%s' no existe." % (ruta))
 
 
 def esta_en_sesion_interactiva():
@@ -68,6 +66,7 @@ def esta_en_sesion_interactiva():
 
     return False
 
+
 def distancia(a, b):
     """Retorna la distancia entre dos numeros.
 
@@ -79,6 +78,7 @@ def distancia(a, b):
     """
     return abs(b - a)
 
+
 def distancia_entre_dos_puntos((x1, y1), (x2, y2)):
     """Retorna la distancia entre dos puntos en dos dimensiones.
 
@@ -89,6 +89,7 @@ def distancia_entre_dos_puntos((x1, y1), (x2, y2)):
     """
     return math.sqrt(distancia(x1, x2) ** 2 + distancia(y1, y2) ** 2)
 
+
 def distancia_entre_dos_actores(a, b):
     """Retorna la distancia en pixels entre dos actores.
 
@@ -97,6 +98,7 @@ def distancia_entre_dos_actores(a, b):
     """
     return distancia_entre_dos_puntos((a.x, a.y), (b.x, b.y))
 
+
 def actor_mas_cercano_al_actor(actor):
     """Retorna el actor de la escena que esté mas cercano a otro indicado por parámetro.
 
@@ -106,11 +108,12 @@ def actor_mas_cercano_al_actor(actor):
     distancia = 999999
     for actor_cercano in pilas.escena_actual().actores:
         if id(actor_cercano) != id(actor):
-            if distancia_entre_dos_actores(actor,actor_cercano) < distancia:
+            if distancia_entre_dos_actores(actor, actor_cercano) < distancia:
                 actor_mas_cercano = actor_cercano
 
     return actor_mas_cercano
 
+
 def colisionan(a, b):
     """Retorna True si dos actores estan en contacto.
 
@@ -119,6 +122,7 @@ def colisionan(a, b):
     """
     return distancia_entre_dos_actores(a, b) < a.radio_de_colision + b.radio_de_colision
 
+
 def interpolable(f):
     """Decorador que se aplica a un metodo para que permita animaciones de interpolaciones.
 
@@ -155,6 +159,7 @@ def interpolable(f):
 
     return inner
 
+
 def hacer_coordenada_mundo(x, y):
     """Convierte una coordenada de pantalla a una coordenada dentro del motor de física.
 
@@ -164,16 +169,18 @@ def hacer_coordenada_mundo(x, y):
     dx, dy = pilas.mundo.motor.centro_fisico()
     return (x + dx, dy - y)
 
+
 def hacer_coordenada_pantalla_absoluta(x, y):
     # TODO: Duplicado del codigo anterior?
     dx, dy = pilas.mundo.motor.centro_fisico()
     return (x + dx, dy - y)
 
+
 def listar_actores_en_consola():
     """Imprime una lista de todos los actores en la escena sobre la consola."""
     todos = pilas.escena_actual().actores
 
-    print "Hay %d actores en la escena:" %(len(todos))
+    print "Hay %d actores en la escena:" % (len(todos))
     print ""
 
     for s in todos:
@@ -181,6 +188,7 @@ def listar_actores_en_consola():
 
     print ""
 
+
 def obtener_angulo_entre(punto_a, punto_b):
     """Retorna el ángulo entro dos puntos de la pantalla.
 
@@ -189,16 +197,19 @@ def obtener_angulo_entre(punto_a, punto_b):
     """
     (x, y) = punto_a
     (x1, y1) = punto_b
-    return math.degrees(math.atan2(y1 - y, x1 -x))
+    return math.degrees(math.atan2(y1 - y, x1 - x))
+
 
 def convertir_de_posicion_relativa_a_fisica(x, y):
     dx, dy = pilas.mundo.motor.centro_fisico()
     return (x + dx, dy - y)
 
+
 def convertir_de_posicion_fisica_relativa(x, y):
     dx, dy = pilas.mundo.motor.centro_fisico()
     return (x - dx, dy - y)
 
+
 def calcular_tiempo_en_recorrer(distancia_en_pixeles, velocidad):
     """Calcula el tiempo que se tardará en recorrer una distancia en
     pixeles con una velocidad constante.
@@ -211,6 +222,7 @@ def calcular_tiempo_en_recorrer(distancia_en_pixeles, velocidad):
     else:
         return 0
 
+
 def interpolar(valor_o_valores, duracion=1, demora=0, tipo='lineal'):
     """Retorna un objeto que representa cambios de atributos progresivos.
 
@@ -230,19 +242,19 @@ def interpolar(valor_o_valores, duracion=1, demora=0, tipo='lineal'):
     import interpolaciones
 
     algoritmos = {
-            'lineal': interpolaciones.Lineal,
-            'aceleracion_gradual': interpolaciones.AceleracionGradual,
-            'desaceleracion_gradual': interpolaciones.DesaceleracionGradual,
-            'rebote_inicial': interpolaciones.ReboteInicial,
-            'rebote_final': interpolaciones.ReboteFinal,
-            'elastico_inicial': interpolaciones.ElasticoInicial,
-            'elastico_final': interpolaciones.ElasticoFinal
-            }
+        'lineal': interpolaciones.Lineal,
+        'aceleracion_gradual': interpolaciones.AceleracionGradual,
+        'desaceleracion_gradual': interpolaciones.DesaceleracionGradual,
+        'rebote_inicial': interpolaciones.ReboteInicial,
+        'rebote_final': interpolaciones.ReboteFinal,
+        'elastico_inicial': interpolaciones.ElasticoInicial,
+        'elastico_final': interpolaciones.ElasticoFinal
+    }
 
-    if algoritmos.has_key(tipo):
+    if tipo in algoritmos:
         clase = algoritmos[tipo]
     else:
-        raise ValueError("El tipo de interpolacion %s es invalido" %(tipo))
+        raise ValueError("El tipo de interpolacion %s es invalido" % (tipo))
 
     # Permite que los valores de interpolacion sean un numero o una lista.
     if not isinstance(valor_o_valores, list):
@@ -264,17 +276,20 @@ def deneter_interpolacion(objeto, propiedad):
         getattr(objeto, setter)
         pilas.escena_actual().tweener.removeTweeningFromObjectField(objeto, setter)
     except:
-        print "El obejto %s no tiene esa propiedad %s" %(objeto.__class__.__name__, setter)
+        print "El obejto %s no tiene esa propiedad %s" % (objeto.__class__.__name__, setter)
+
 
 def obtener_area():
     """Retorna el area que ocupa la ventana"""
     return pilas.mundo.motor.obtener_area()
 
+
 def obtener_bordes():
     """Retorna los bordes de la pantalla en forma de tupla."""
     ancho, alto = pilas.mundo.motor.obtener_area()
     return -ancho/2, ancho/2, alto/2, -alto/2
 
+
 def obtener_area_de_texto(texto):
     """Informa el ancho y alto que necesitara un texto para imprimirse.
 
@@ -282,6 +297,7 @@ def obtener_area_de_texto(texto):
     """
     return pilas.mundo.motor.obtener_area_de_texto(texto)
 
+
 def realizar_pruebas():
     """Imprime pruebas en pantalla para detectar si pilas tiene todas las dependencias instaladas."""
     print "Realizando pruebas de dependencias:"
@@ -319,6 +335,7 @@ def realizar_pruebas():
     except ImportError:
         print "Cuidado -> no se encuentra PIL."
 
+
 def ver_codigo(objeto, imprimir, retornar):
     """Imprime en pantalla el codigo fuente asociado a un objeto.
 
@@ -339,10 +356,12 @@ def ver_codigo(objeto, imprimir, retornar):
     if retornar:
         return codigo
 
+
 def obtener_uuid():
     """Genera un identificador único."""
     return str(uuid.uuid4())
 
+
 def abrir_archivo_con_aplicacion_predeterminada(ruta_al_archivo):
     """Intenta abrir un archivo con la herramienta recomenda por el sistema operativo.
 
@@ -355,6 +374,7 @@ def abrir_archivo_con_aplicacion_predeterminada(ruta_al_archivo):
     elif os.name == 'posix':
         subprocess.call(('xdg-open', ruta_al_archivo))
 
+
 def centrar_ventana(widget):
     """Coloca la ventana o widget directamente en el centro del escritorio.
 
@@ -364,6 +384,7 @@ def centrar_ventana(widget):
     desktop = QtGui.QApplication.desktop()
     widget.move(desktop.screen().rect().center() - widget.rect().center())
 
+
 def descargar_archivo_desde_internet(parent, url, archivo_destino):
     """Inicia la descarga de una archivo desde Internet.
 
@@ -375,6 +396,7 @@ def descargar_archivo_desde_internet(parent, url, archivo_destino):
     ventana = descargar.Descargar(parent, url, archivo_destino)
     ventana.show()
 
+
 def imprimir_todos_los_eventos():
     """Muestra en consola los eventos activos y a quienes invocan"""
     import pilas
@@ -387,6 +409,7 @@ def imprimir_todos_los_eventos():
             attributo.imprimir_funciones_conectadas()
             print ""
 
+
 def habilitar_depuracion():
     """Permite habilitar un breakpoint para depuracion una vez inicializado pilas."""
     from PyQt4.QtCore import pyqtRemoveInputHook
@@ -394,6 +417,7 @@ def habilitar_depuracion():
     pyqtRemoveInputHook()
     set_trace()
 
+
 def mostrar_mensaje_de_error_y_salir(motivo):
     """Muestra un mensaje de error y termina con la ejecución de pilas.
 
@@ -409,6 +433,7 @@ def mostrar_mensaje_de_error_y_salir(motivo):
     app.exit()
     sys.exit(1)
 
+
 def obtener_archivo_a_ejecutar_desde_argv():
     """Obtiene la ruta del archivo a ejecutar desde la linea de argumentos del programa."""
     import sys
@@ -420,22 +445,23 @@ def obtener_archivo_a_ejecutar_desde_argv():
 
     return " ".join(argv[1:])
 
+
 def procesar_argumentos_desde_command_line():
     from optparse import OptionParser
 
     analizador = OptionParser()
 
     analizador.add_option("-t", "--test", dest="test",
-            action="store_true", default=False,
-            help="Invoca varias pruebas verificar el funcionamiento de pilas")
+                          action="store_true", default=False,
+                          help="Invoca varias pruebas verificar el funcionamiento de pilas")
 
     analizador.add_option("-v", "--version", dest="version",
-            action="store_true", default=False,
-            help="Consulta la version instalada")
+                          action="store_true", default=False,
+                          help="Consulta la version instalada")
 
     analizador.add_option("-i", "--interprete", dest="interprete",
-            action="store_true", default=False,
-            help="Abre el interprete interactivo")
+                          action="store_true", default=False,
+                          help="Abre el interprete interactivo")
 
     (opciones, argumentos) = analizador.parse_args()
     return (opciones, argumentos)
@@ -454,10 +480,10 @@ def iniciar_asistente_desde_argumentos():
         archivo_a_ejecutar = obtener_archivo_a_ejecutar_desde_argv()
 
         if not os.path.exists(archivo_a_ejecutar):
-            mostrar_mensaje_de_error_y_salir("El archivo '%s' no existe o no se puede leer." %(archivo_a_ejecutar))
+            mostrar_mensaje_de_error_y_salir("El archivo '%s' no existe o no se puede leer." % (archivo_a_ejecutar))
 
         if not 'text/x-python' in mimetypes.guess_type(archivo_a_ejecutar):
-            mostrar_mensaje_de_error_y_salir("El archivo '%s' no parece un script python. Intenta con un archivo .py" %(archivo_a_ejecutar))
+            mostrar_mensaje_de_error_y_salir("El archivo '%s' no parece un script python. Intenta con un archivo .py" % (archivo_a_ejecutar))
 
         ## Intenta ejecutar el script como un programa de pilas.
         try:
@@ -482,4 +508,3 @@ def iniciar_asistente_desde_argumentos():
     else:
         import pilas
         pilas.abrir_asistente()
-
